==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/router/src/io/include/mysqlrouter/io_thread.h <==
/*
  Copyright (c) 2020, 2023, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTER_IO_THREAD_INCLUDED
#define ROUTER_IO_THREAD_INCLUDED

#include <cstddef>  // size_t
#include <memory>   // make_unique
#include <string>
#include <thread>

#include "mysql/harness/net_ts/impl/socket_service.h"
#include "mysql/harness/net_ts/io_context.h"
#include "mysqlrouter/io_backend.h"
#include "mysqlrouter/thread_affinity.h"

class IoThread {
 public:
  IoThread(size_t ndx, std::bitset<ThreadAffinity::max_cpus> cpu_affinity,
           const std::string &backend_name = "poll")
      : ndx_{ndx},
        cpu_affinity_{cpu_affinity},
        io_ctx_{std::make_unique<net::impl::socket::SocketService>(),
                IoBackend::backend(backend_name)},
        thr_{&IoThread::operator(), this} {}

  ~IoThread() {
    stop();
    join();
  }

  net::io_context &context() noexcept { return io_ctx_; }

  void operator()();

  void stop() { io_ctx_.stop(); }

  void join() {
    if (thr_.joinable()) thr_.join();
  }

  std::bitset<ThreadAffinity::max_cpus> cpu_affinity() const {
    return cpu_affinity_;
  }

 private:
  size_t ndx_;
  std::bitset<ThreadAffinity::max_cpus> cpu_affinity_;

  net::io_context io_ctx_;

  std::thread thr_;
};

#endif

==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/router/src/io/include/mysqlrouter/io_thread.h <==
/*
  Copyright (c) 2020, 2024, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTER_IO_THREAD_INCLUDED
#define ROUTER_IO_THREAD_INCLUDED

#include <cstddef>  // size_t
#include <memory>   // make_unique
#include <string>
#include <thread>

#include "mysql/harness/net_ts/impl/socket_service.h"
#include "mysql/harness/net_ts/io_context.h"
#include "mysqlrouter/io_backend.h"
#include "mysqlrouter/thread_affinity.h"

class IoThread {
 public:
  IoThread(size_t ndx, std::bitset<ThreadAffinity::max_cpus> cpu_affinity,
           const std::string &backend_name = "poll")
      : ndx_{ndx},
        cpu_affinity_{cpu_affinity},
        io_ctx_{std::make_unique<net::impl::socket::SocketService>(),
                IoBackend::backend(backend_name)},
        thr_{&IoThread::operator(), this} {}

  ~IoThread() {
    stop();
    join();
  }

  net::io_context &context() noexcept { return io_ctx_; }

  void operator()();

  void stop() { io_ctx_.stop(); }

  void join() {
    if (thr_.joinable()) thr_.join();
  }

  std::bitset<ThreadAffinity::max_cpus> cpu_affinity() const {
    return cpu_affinity_;
  }

 private:
  size_t ndx_;
  std::bitset<ThreadAffinity::max_cpus> cpu_affinity_;

  net::io_context io_ctx_;

  std::thread thr_;
};

#endif
